#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-instances
version:              3.4
visibility:           public
id:                   vector-instances-3.4-ARqy2VzmjkjE1IiTNTsSvp
key:                  vector-instances-3.4-ARqy2VzmjkjE1IiTNTsSvp
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
category:             Data, Data Structures
abi:                  1d7c3f6b0cbe352d71e36f05c998684c
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-8.10.5/site-local/vector-instances-3.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/vector-instances-3.4
hs-libraries:         HSvector-instances-3.4-ARqy2VzmjkjE1IiTNTsSvp
depends:
    base-4.14.2.0 comonad-5.0.8-8a10YHmXJVq2BoDg3RtKOL
    hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    keys-3.12.3-8KSpkQJsgmd9mHbH8OuRcZ
    pointed-5.0.2-WAb0SEjUh9J1Fo4Z6rgkC
    semigroupoids-5.3.5-1MUCoMhFnfRKlT8x21E1a0
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

